@@ -11,6 +11,7 @@ from dust_extinction.parameter_averages import (
     G16,
     F19,
     D22,
+    G23,
 )
 from dust_extinction.shapes import FM90, P92, G21
 from dust_extinction.averages import (
@@ -30,7 +31,7 @@ from dust_extinction.averages import (
 )
 from dust_extinction.grain_models import DBP90, WD01, D03, ZDA04, C11, J13
 
-param_ave_models_Rv = [CCM89, O94, F99, F04, VCG04, GCC09, M14, F19, D22]
+param_ave_models_Rv = [CCM89, O94, F99, F04, VCG04, GCC09, M14, F19, D22, G23]
 param_ave_models_Rv_fA = [G16]
 param_ave_models = param_ave_models_Rv + param_ave_models_Rv_fA
 shape_models = [FM90, P92, G21]
