@@ -42,7 +42,7 @@ def test_units_nowarning_expected(model):
 def test_invalid_Rv_input(model, Rv_invalid):
     with pytest.raises(InputParameterError) as exc:
         model(Rv=Rv_invalid)
-    assert exc.value.args[0] == "parameter Rv must be between 2.0 and 6.0"
+    assert "parameter Rv must be between" in exc.value.args[0]
 
 
 @pytest.mark.parametrize("RvA_invalid", [-1.0, 0.0, 1.9, 6.1, 10.0])
